@@ -4,8 +4,8 @@ import requests
 class Weather:
     """
     Creates a Weather object by getting the following as input: api-key, city name or latitude/longitude coordinates,
-    temperature units (optional). If no units (metric/imperial) are supplied, kelvin units are applied as the default
-    units convention.
+    temperature units (optional). If no units (metric / imperial) are given, kelvin units are applied as the default
+    temperature units convention.
     """
 
     def __init__(self, api_key, city=None, lat=None, lon=None, units=None):
@@ -25,14 +25,13 @@ class Weather:
 
     def next_24_hours(self):
         """
-        Returns 3-hour weather data for the next 24 hours as a dict.
+        Returns full 3-hour weather data for the next 24 hours as a dict.
         """
-        all_data = self.data['list'][:9]
-        return all_data
+        return self.data['list'][:9]
 
     def next_24_hours_basic(self):
         """
-        Returns 3-hour basic weather data (date, time, temperature, sky condition, sky condition icon code)
+        Returns 3-hour basic weather data (datetime, temperature, sky condition, sky condition icon code)
         for the next 24 hours as a list of tuples.
         """
         basic_data = []
